commit 9e80ae182e30c58857c8e30260f7fc3788dd7597
Author: Jan Schulz-Hofen <yeah@yeahrock.de>
Date:   Sun Sep 11 18:48:55 2011 +0200

    * enable user to add a newly created status to all workflows at once

diff --git a/app/controllers/issue_statuses_controller.rb b/app/controllers/issue_statuses_controller.rb
index b4b754b..2c38e9c 100644
--- a/app/controllers/issue_statuses_controller.rb
+++ b/app/controllers/issue_statuses_controller.rb
@@ -35,6 +35,23 @@ class IssueStatusesController < ApplicationController
   def create
     @issue_status = IssueStatus.new(params[:issue_status])
     if @issue_status.save
+      if params[:add_to_all_workflows]
+        begin
+          Workflow.transaction do
+            Tracker.all.each do |tracker|
+              Role.all.each do |role|
+                (IssueStatus.all - [@issue_status]).each do |status|
+                  Workflow.create! :tracker_id => tracker.id, :old_status => @issue_status, :new_status => status, :role => role # from
+                  Workflow.create! :tracker_id => tracker.id, :old_status => status, :new_status => @issue_status, :role => role # to
+                end
+                Workflow.create! :tracker_id => tracker.id, :old_status => @issue_status, :new_status => @issue_status, :role => role # self-to-self
+              end
+            end
+          end
+        rescue
+          flash[:warning] = l(:error_unable_add_to_workflows)
+        end
+      end
       flash[:notice] = l(:notice_successful_create)
       redirect_to :action => 'index'
     else
diff --git a/app/views/issue_statuses/_form.rhtml b/app/views/issue_statuses/_form.rhtml
index 20c333e..84a3b25 100644
--- a/app/views/issue_statuses/_form.rhtml
+++ b/app/views/issue_statuses/_form.rhtml
@@ -1,6 +1,6 @@
 <%= error_messages_for 'issue_status' %>
 
-<div class="box">
+<div class="box tabular">
 <!--[form:issue_status]-->
 <p><label for="issue_status_name"><%=l(:field_name)%><span class="required"> *</span></label>
 <%= text_field 'issue_status', 'name'  %></p>
diff --git a/app/views/issue_statuses/new.rhtml b/app/views/issue_statuses/new.rhtml
index bc74c8d..2b818e1 100644
--- a/app/views/issue_statuses/new.rhtml
+++ b/app/views/issue_statuses/new.rhtml
@@ -1,6 +1,7 @@
 <h2><%= link_to l(:label_issue_status_plural), :controller => 'issue_statuses', :action => 'index' %> &#187; <%=l(:label_issue_status_new)%></h2>
 
-<% form_tag({:action => 'create'}, :class => "tabular") do %>
+<% form_tag({:action => 'create'}) do %>
   <%= render :partial => 'form' %>
+  <p><label><%= check_box_tag 'add_to_all_workflows', 1, true %> <%= l(:label_add_to_all_workflows) %></label></p>
   <%= submit_tag l(:button_create) %>
 <% end %>
diff --git a/config/locales/bg.yml b/config/locales/bg.yml
index 02678a8..22d7afc 100644
--- a/config/locales/bg.yml
+++ b/config/locales/bg.yml
@@ -1282,3 +1282,5 @@ bg:
   field_assigned_to_role: Member of Role
   button_edit_associated_wikipage: "Edit associated Wiki page: {{page_title}}"
   text_are_you_sure_with_children: Delete issue and all child issues?
+  label_add_to_all_workflows: Add to all workflows
+  error_unable_add_to_workflows: Unable to add issue status to all workflows. Please add it manually.
diff --git a/config/locales/bs.yml b/config/locales/bs.yml
index 0a8f261..c9c8ee0 100644
--- a/config/locales/bs.yml
+++ b/config/locales/bs.yml
@@ -991,3 +991,5 @@ bs:
   label_git_report_last_commit: Report last commit for files and directories
   text_scm_config: You can configure your scm commands in config/configuration.yml. Please restart the application after editing it.
   text_scm_command_not_available: Scm command is not available. Please check settings on the administration panel.
+  label_add_to_all_workflows: Add to all workflows
+  error_unable_add_to_workflows: Unable to add issue status to all workflows. Please add it manually.
diff --git a/config/locales/ca.yml b/config/locales/ca.yml
index 2bf9422..1e2fe23 100644
--- a/config/locales/ca.yml
+++ b/config/locales/ca.yml
@@ -980,3 +980,5 @@ ca:
   label_git_report_last_commit: Report last commit for files and directories
   text_scm_config: You can configure your scm commands in config/configuration.yml. Please restart the application after editing it.
   text_scm_command_not_available: Scm command is not available. Please check settings on the administration panel.
+  label_add_to_all_workflows: Add to all workflows
+  error_unable_add_to_workflows: Unable to add issue status to all workflows. Please add it manually.
diff --git a/config/locales/cs.yml b/config/locales/cs.yml
index ab54bf2..3f524c8 100644
--- a/config/locales/cs.yml
+++ b/config/locales/cs.yml
@@ -981,3 +981,5 @@ cs:
   label_git_report_last_commit: Report last commit for files and directories
   text_scm_config: You can configure your scm commands in config/configuration.yml. Please restart the application after editing it.
   text_scm_command_not_available: Scm command is not available. Please check settings on the administration panel.
+  label_add_to_all_workflows: Add to all workflows
+  error_unable_add_to_workflows: Unable to add issue status to all workflows. Please add it manually.
diff --git a/config/locales/da.yml b/config/locales/da.yml
index 6271f7b..864e5a9 100644
--- a/config/locales/da.yml
+++ b/config/locales/da.yml
@@ -994,3 +994,5 @@ da:
   label_git_report_last_commit: Report last commit for files and directories
   text_scm_config: You can configure your scm commands in config/configuration.yml. Please restart the application after editing it.
   text_scm_command_not_available: Scm command is not available. Please check settings on the administration panel.
+  label_add_to_all_workflows: Add to all workflows
+  error_unable_add_to_workflows: Unable to add issue status to all workflows. Please add it manually.
diff --git a/config/locales/de.yml b/config/locales/de.yml
index cd99fe2..1e7fe2d 100644
--- a/config/locales/de.yml
+++ b/config/locales/de.yml
@@ -994,3 +994,5 @@ de:
   label_git_report_last_commit: Bericht des letzten Commits für Dateien und Verzeichnisse
   text_scm_config: You can configure your scm commands in config/configuration.yml. Please restart the application after editing it.
   text_scm_command_not_available: Scm command is not available. Please check settings on the administration panel.
+  label_add_to_all_workflows: Zu allen Workflows hinzufügen
+  error_unable_add_to_workflows: Der Status konnte nicht zu allen Workflows hinzugefügt werden. Bitte fügen Sie ihn manuell hinzu.
diff --git a/config/locales/el.yml b/config/locales/el.yml
index 956d8ac..6e944a9 100644
--- a/config/locales/el.yml
+++ b/config/locales/el.yml
@@ -977,3 +977,5 @@ el:
   label_git_report_last_commit: Report last commit for files and directories
   text_scm_config: You can configure your scm commands in config/configuration.yml. Please restart the application after editing it.
   text_scm_command_not_available: Scm command is not available. Please check settings on the administration panel.
+  label_add_to_all_workflows: Add to all workflows
+  error_unable_add_to_workflows: Unable to add issue status to all workflows. Please add it manually.
diff --git a/config/locales/en-GB.yml b/config/locales/en-GB.yml
index 9fe7309..9dcd2c2 100644
--- a/config/locales/en-GB.yml
+++ b/config/locales/en-GB.yml
@@ -980,3 +980,5 @@ en-GB:
   label_git_report_last_commit: Report last commit for files and directories
   text_scm_config: You can configure your scm commands in config/configuration.yml. Please restart the application after editing it.
   text_scm_command_not_available: Scm command is not available. Please check settings on the administration panel.
+  label_add_to_all_workflows: Add to all workflows
+  error_unable_add_to_workflows: Unable to add issue status to all workflows. Please add it manually.
diff --git a/config/locales/en.yml b/config/locales/en.yml
index a8fc36f..32df48b 100644
--- a/config/locales/en.yml
+++ b/config/locales/en.yml
@@ -188,6 +188,7 @@ en:
   error_workflow_copy_source: 'Please select a source tracker or role'
   error_workflow_copy_target: 'Please select target tracker(s) and role(s)'
   error_unable_delete_issue_status: 'Unable to delete issue status'
+  error_unable_add_to_workflows: 'Unable to add issue status to all workflows. Please add it manually.'
   error_unable_to_connect: "Unable to connect (%{value})"
   warning_attachments_not_saved: "%{count} file(s) could not be saved."
   
@@ -486,6 +487,7 @@ en:
   label_issue_status: Issue status
   label_issue_status_plural: Issue statuses
   label_issue_status_new: New status
+  label_add_to_all_workflows: Add to all workflows
   label_issue_category: Issue category
   label_issue_category_plural: Issue categories
   label_issue_category_new: New category
diff --git a/config/locales/es.yml b/config/locales/es.yml
index 32f18b3..8e86ccc 100644
--- a/config/locales/es.yml
+++ b/config/locales/es.yml
@@ -1014,3 +1014,5 @@ es:
   label_git_report_last_commit: Report last commit for files and directories
   text_scm_config: You can configure your scm commands in config/configuration.yml. Please restart the application after editing it.
   text_scm_command_not_available: Scm command is not available. Please check settings on the administration panel.
+  label_add_to_all_workflows: Add to all workflows
+  error_unable_add_to_workflows: Unable to add issue status to all workflows. Please add it manually.
diff --git a/config/locales/eu.yml b/config/locales/eu.yml
index a21f2d5..1e4e232 100644
--- a/config/locales/eu.yml
+++ b/config/locales/eu.yml
@@ -981,3 +981,5 @@ eu:
   label_git_report_last_commit: Report last commit for files and directories
   text_scm_config: You can configure your scm commands in config/configuration.yml. Please restart the application after editing it.
   text_scm_command_not_available: Scm command is not available. Please check settings on the administration panel.
+  label_add_to_all_workflows: Add to all workflows
+  error_unable_add_to_workflows: Unable to add issue status to all workflows. Please add it manually.
diff --git a/config/locales/fa.yml b/config/locales/fa.yml
index 6bba8ab..208f4f5 100644
--- a/config/locales/fa.yml
+++ b/config/locales/fa.yml
@@ -979,3 +979,5 @@ fa:
   label_git_report_last_commit: Report last commit for files and directories
   text_scm_config: You can configure your scm commands in config/configuration.yml. Please restart the application after editing it.
   text_scm_command_not_available: Scm command is not available. Please check settings on the administration panel.
+  label_add_to_all_workflows: Add to all workflows
+  error_unable_add_to_workflows: Unable to add issue status to all workflows. Please add it manually.
diff --git a/config/locales/fi.yml b/config/locales/fi.yml
index cad16b7..f083af4 100644
--- a/config/locales/fi.yml
+++ b/config/locales/fi.yml
@@ -998,3 +998,5 @@ fi:
   label_git_report_last_commit: Report last commit for files and directories
   text_scm_config: You can configure your scm commands in config/configuration.yml. Please restart the application after editing it.
   text_scm_command_not_available: Scm command is not available. Please check settings on the administration panel.
+  label_add_to_all_workflows: Add to all workflows
+  error_unable_add_to_workflows: Unable to add issue status to all workflows. Please add it manually.
diff --git a/config/locales/fr.yml b/config/locales/fr.yml
index 90e84b2..a8342f7 100644
--- a/config/locales/fr.yml
+++ b/config/locales/fr.yml
@@ -992,3 +992,5 @@ fr:
   label_git_report_last_commit: Afficher le dernier commit des fichiers et répertoires
   text_scm_config: Vous pouvez configurer les commandes des SCM dans config/configuration.yml. Redémarrer l'application après modification.
   text_scm_command_not_available: Ce SCM n'est pas disponible. Vérifier les paramètres dans la section administration.
+  label_add_to_all_workflows: Ajouter à tous les workflows
+  error_unable_add_to_workflows: Impossible d'ajouter le statut à tous les workflows. Veuillez l'ajouter manuellement.
diff --git a/config/locales/gl.yml b/config/locales/gl.yml
index 81d16e3..f6a5323 100644
--- a/config/locales/gl.yml
+++ b/config/locales/gl.yml
@@ -989,3 +989,5 @@ gl:
   label_git_report_last_commit: Report last commit for files and directories
   text_scm_config: You can configure your scm commands in config/configuration.yml. Please restart the application after editing it.
   text_scm_command_not_available: Scm command is not available. Please check settings on the administration panel.
+  label_add_to_all_workflows: Add to all workflows
+  error_unable_add_to_workflows: Unable to add issue status to all workflows. Please add it manually.
diff --git a/config/locales/he.yml b/config/locales/he.yml
index d610513..d53e38b 100644
--- a/config/locales/he.yml
+++ b/config/locales/he.yml
@@ -982,3 +982,5 @@ he:
   label_git_report_last_commit: Report last commit for files and directories
   text_scm_config: You can configure your scm commands in config/configuration.yml. Please restart the application after editing it.
   text_scm_command_not_available: Scm command is not available. Please check settings on the administration panel.
+  label_add_to_all_workflows: Add to all workflows
+  error_unable_add_to_workflows: Unable to add issue status to all workflows. Please add it manually.
diff --git a/config/locales/hr.yml b/config/locales/hr.yml
index fc450e9..0caffe4 100644
--- a/config/locales/hr.yml
+++ b/config/locales/hr.yml
@@ -984,3 +984,5 @@ hr:
   label_git_report_last_commit: Report last commit for files and directories
   text_scm_config: You can configure your scm commands in config/configuration.yml. Please restart the application after editing it.
   text_scm_command_not_available: Scm command is not available. Please check settings on the administration panel.
+  label_add_to_all_workflows: Add to all workflows
+  error_unable_add_to_workflows: Unable to add issue status to all workflows. Please add it manually.
diff --git a/config/locales/hu.yml b/config/locales/hu.yml
index 528d7b5..2467a42 100644
--- a/config/locales/hu.yml
+++ b/config/locales/hu.yml
@@ -996,3 +996,5 @@
   label_git_report_last_commit: Report last commit for files and directories
   text_scm_config: You can configure your scm commands in config/configuration.yml. Please restart the application after editing it.
   text_scm_command_not_available: Scm command is not available. Please check settings on the administration panel.
+  label_add_to_all_workflows: Add to all workflows
+  error_unable_add_to_workflows: Unable to add issue status to all workflows. Please add it manually.
diff --git a/config/locales/id.yml b/config/locales/id.yml
index 018eb9f..e67fcdc 100644
--- a/config/locales/id.yml
+++ b/config/locales/id.yml
@@ -985,3 +985,5 @@ id:
   label_git_report_last_commit: Report last commit for files and directories
   text_scm_config: You can configure your scm commands in config/configuration.yml. Please restart the application after editing it.
   text_scm_command_not_available: Scm command is not available. Please check settings on the administration panel.
+  label_add_to_all_workflows: Add to all workflows
+  error_unable_add_to_workflows: Unable to add issue status to all workflows. Please add it manually.
diff --git a/config/locales/it.yml b/config/locales/it.yml
index c159373..125653a 100644
--- a/config/locales/it.yml
+++ b/config/locales/it.yml
@@ -978,3 +978,5 @@ it:
   label_git_report_last_commit: Report last commit for files and directories
   text_scm_config: You can configure your scm commands in config/configuration.yml. Please restart the application after editing it.
   text_scm_command_not_available: Scm command is not available. Please check settings on the administration panel.
+  label_add_to_all_workflows: Add to all workflows
+  error_unable_add_to_workflows: Unable to add issue status to all workflows. Please add it manually.
diff --git a/config/locales/ja.yml b/config/locales/ja.yml
index b44bb10..e963b76 100644
--- a/config/locales/ja.yml
+++ b/config/locales/ja.yml
@@ -999,3 +999,5 @@ ja:
   permission_set_issues_private: チケットをプライベートに設定
   label_issues_visibility_public: プライベートチケット以外
   text_issues_destroy_descendants_confirmation: %{count}個の子チケットも削除されます。
+  label_add_to_all_workflows: Add to all workflows
+  error_unable_add_to_workflows: Unable to add issue status to all workflows. Please add it manually.
diff --git a/config/locales/ko.yml b/config/locales/ko.yml
index 4cdbcf2..2cccfb9 100644
--- a/config/locales/ko.yml
+++ b/config/locales/ko.yml
@@ -1029,3 +1029,5 @@ ko:
   label_git_report_last_commit: Report last commit for files and directories
   text_scm_config: You can configure your scm commands in config/configuration.yml. Please restart the application after editing it.
   text_scm_command_not_available: Scm command is not available. Please check settings on the administration panel.
+  label_add_to_all_workflows: Add to all workflows
+  error_unable_add_to_workflows: Unable to add issue status to all workflows. Please add it manually.
diff --git a/config/locales/lt.yml b/config/locales/lt.yml
index 092fed0..88be530 100644
--- a/config/locales/lt.yml
+++ b/config/locales/lt.yml
@@ -1037,3 +1037,5 @@ lt:
   label_git_report_last_commit: Report last commit for files and directories
   text_scm_config: You can configure your scm commands in config/configuration.yml. Please restart the application after editing it.
   text_scm_command_not_available: Scm command is not available. Please check settings on the administration panel.
+  label_add_to_all_workflows: Add to all workflows
+  error_unable_add_to_workflows: Unable to add issue status to all workflows. Please add it manually.
diff --git a/config/locales/lv.yml b/config/locales/lv.yml
index 14c22a8..1db033a 100644
--- a/config/locales/lv.yml
+++ b/config/locales/lv.yml
@@ -972,3 +972,5 @@ lv:
   label_git_report_last_commit: Report last commit for files and directories
   text_scm_config: You can configure your scm commands in config/configuration.yml. Please restart the application after editing it.
   text_scm_command_not_available: Scm command is not available. Please check settings on the administration panel.
+  label_add_to_all_workflows: Add to all workflows
+  error_unable_add_to_workflows: Unable to add issue status to all workflows. Please add it manually.
diff --git a/config/locales/mk.yml b/config/locales/mk.yml
index 5b10ce2..51f2210 100644
--- a/config/locales/mk.yml
+++ b/config/locales/mk.yml
@@ -977,3 +977,5 @@ mk:
   label_git_report_last_commit: Report last commit for files and directories
   text_scm_config: You can configure your scm commands in config/configuration.yml. Please restart the application after editing it.
   text_scm_command_not_available: Scm command is not available. Please check settings on the administration panel.
+  label_add_to_all_workflows: Add to all workflows
+  error_unable_add_to_workflows: Unable to add issue status to all workflows. Please add it manually.
diff --git a/config/locales/mn.yml b/config/locales/mn.yml
index 9d000a9..3c510f6 100644
--- a/config/locales/mn.yml
+++ b/config/locales/mn.yml
@@ -978,3 +978,5 @@ mn:
   label_git_report_last_commit: Report last commit for files and directories
   text_scm_config: You can configure your scm commands in config/configuration.yml. Please restart the application after editing it.
   text_scm_command_not_available: Scm command is not available. Please check settings on the administration panel.
+  label_add_to_all_workflows: Add to all workflows
+  error_unable_add_to_workflows: Unable to add issue status to all workflows. Please add it manually.
diff --git a/config/locales/nl.yml b/config/locales/nl.yml
index ab2c6d9..b0e453f 100644
--- a/config/locales/nl.yml
+++ b/config/locales/nl.yml
@@ -959,3 +959,5 @@ nl:
   label_git_report_last_commit: Report last commit for files and directories
   text_scm_config: You can configure your scm commands in config/configuration.yml. Please restart the application after editing it.
   text_scm_command_not_available: Scm command is not available. Please check settings on the administration panel.
+  label_add_to_all_workflows: Add to all workflows
+  error_unable_add_to_workflows: Unable to add issue status to all workflows. Please add it manually.
diff --git a/config/locales/no.yml b/config/locales/no.yml
index bce9a60..c31eca0 100644
--- a/config/locales/no.yml
+++ b/config/locales/no.yml
@@ -964,3 +964,5 @@
   label_git_report_last_commit: Report last commit for files and directories
   text_scm_config: You can configure your scm commands in config/configuration.yml. Please restart the application after editing it.
   text_scm_command_not_available: Scm command is not available. Please check settings on the administration panel.
+  label_add_to_all_workflows: Add to all workflows
+  error_unable_add_to_workflows: Unable to add issue status to all workflows. Please add it manually.
diff --git a/config/locales/pl.yml b/config/locales/pl.yml
index 89f10dc..e19a185 100644
--- a/config/locales/pl.yml
+++ b/config/locales/pl.yml
@@ -994,3 +994,5 @@ pl:
   label_git_report_last_commit: Report last commit for files and directories
   text_scm_config: You can configure your scm commands in config/configuration.yml. Please restart the application after editing it.
   text_scm_command_not_available: Scm command is not available. Please check settings on the administration panel.
+  label_add_to_all_workflows: Add to all workflows
+  error_unable_add_to_workflows: Unable to add issue status to all workflows. Please add it manually.
diff --git a/config/locales/pt-BR.yml b/config/locales/pt-BR.yml
index 41b74f0..b3f6fcf 100644
--- a/config/locales/pt-BR.yml
+++ b/config/locales/pt-BR.yml
@@ -997,3 +997,5 @@ pt-BR:
   label_git_report_last_commit: Report last commit for files and directories
   text_scm_config: You can configure your scm commands in config/configuration.yml. Please restart the application after editing it.
   text_scm_command_not_available: Scm command is not available. Please check settings on the administration panel.
+  label_add_to_all_workflows: Add to all workflows
+  error_unable_add_to_workflows: Unable to add issue status to all workflows. Please add it manually.
diff --git a/config/locales/pt.yml b/config/locales/pt.yml
index b0f1666..adb6ec5 100644
--- a/config/locales/pt.yml
+++ b/config/locales/pt.yml
@@ -982,3 +982,5 @@ pt:
   label_git_report_last_commit: Report last commit for files and directories
   text_scm_config: You can configure your scm commands in config/configuration.yml. Please restart the application after editing it.
   text_scm_command_not_available: Scm command is not available. Please check settings on the administration panel.
+  label_add_to_all_workflows: Add to all workflows
+  error_unable_add_to_workflows: Unable to add issue status to all workflows. Please add it manually.
diff --git a/config/locales/ro.yml b/config/locales/ro.yml
index 5387800..07ce3d7 100644
--- a/config/locales/ro.yml
+++ b/config/locales/ro.yml
@@ -970,3 +970,5 @@ ro:
   label_git_report_last_commit: Report last commit for files and directories
   text_scm_config: You can configure your scm commands in config/configuration.yml. Please restart the application after editing it.
   text_scm_command_not_available: Scm command is not available. Please check settings on the administration panel.
+  label_add_to_all_workflows: Add to all workflows
+  error_unable_add_to_workflows: Unable to add issue status to all workflows. Please add it manually.
diff --git a/config/locales/ru.yml b/config/locales/ru.yml
index dae94b2..52a2d7c 100644
--- a/config/locales/ru.yml
+++ b/config/locales/ru.yml
@@ -1090,3 +1090,5 @@ ru:
   label_git_report_last_commit: Report last commit for files and directories
   text_scm_config: You can configure your scm commands in config/configuration.yml. Please restart the application after editing it.
   text_scm_command_not_available: Scm command is not available. Please check settings on the administration panel.
+  label_add_to_all_workflows: Add to all workflows
+  error_unable_add_to_workflows: Unable to add issue status to all workflows. Please add it manually.
diff --git a/config/locales/sk.yml b/config/locales/sk.yml
index 042d50d..ee5d7ba 100644
--- a/config/locales/sk.yml
+++ b/config/locales/sk.yml
@@ -972,3 +972,5 @@ sk:
   label_git_report_last_commit: Report last commit for files and directories
   text_scm_config: You can configure your scm commands in config/configuration.yml. Please restart the application after editing it.
   text_scm_command_not_available: Scm command is not available. Please check settings on the administration panel.
+  label_add_to_all_workflows: Add to all workflows
+  error_unable_add_to_workflows: Unable to add issue status to all workflows. Please add it manually.
diff --git a/config/locales/sl.yml b/config/locales/sl.yml
index 3910089..51e491e 100644
--- a/config/locales/sl.yml
+++ b/config/locales/sl.yml
@@ -973,3 +973,5 @@ sl:
   label_git_report_last_commit: Report last commit for files and directories
   text_scm_config: You can configure your scm commands in config/configuration.yml. Please restart the application after editing it.
   text_scm_command_not_available: Scm command is not available. Please check settings on the administration panel.
+  label_add_to_all_workflows: Add to all workflows
+  error_unable_add_to_workflows: Unable to add issue status to all workflows. Please add it manually.
diff --git a/config/locales/sr-YU.yml b/config/locales/sr-YU.yml
index c25b85e..1e5b273 100644
--- a/config/locales/sr-YU.yml
+++ b/config/locales/sr-YU.yml
@@ -977,3 +977,5 @@ sr-YU:
   label_git_report_last_commit: Report last commit for files and directories
   text_scm_config: You can configure your scm commands in config/configuration.yml. Please restart the application after editing it.
   text_scm_command_not_available: Scm command is not available. Please check settings on the administration panel.
+  label_add_to_all_workflows: Add to all workflows
+  error_unable_add_to_workflows: Unable to add issue status to all workflows. Please add it manually.
diff --git a/config/locales/sr.yml b/config/locales/sr.yml
index 743ac87..89a0e76 100644
--- a/config/locales/sr.yml
+++ b/config/locales/sr.yml
@@ -978,3 +978,5 @@ sr:
   label_git_report_last_commit: Report last commit for files and directories
   text_scm_config: You can configure your scm commands in config/configuration.yml. Please restart the application after editing it.
   text_scm_command_not_available: Scm command is not available. Please check settings on the administration panel.
+  label_add_to_all_workflows: Add to all workflows
+  error_unable_add_to_workflows: Unable to add issue status to all workflows. Please add it manually.
diff --git a/config/locales/sv.yml b/config/locales/sv.yml
index 792fbb7..364a739 100644
--- a/config/locales/sv.yml
+++ b/config/locales/sv.yml
@@ -1018,3 +1018,5 @@ sv:
   label_git_report_last_commit: Report last commit for files and directories
   text_scm_config: You can configure your scm commands in config/configuration.yml. Please restart the application after editing it.
   text_scm_command_not_available: Scm command is not available. Please check settings on the administration panel.
+  label_add_to_all_workflows: Add to all workflows
+  error_unable_add_to_workflows: Unable to add issue status to all workflows. Please add it manually.
diff --git a/config/locales/th.yml b/config/locales/th.yml
index 43e7346..03347ee 100644
--- a/config/locales/th.yml
+++ b/config/locales/th.yml
@@ -974,3 +974,5 @@ th:
   label_git_report_last_commit: Report last commit for files and directories
   text_scm_config: You can configure your scm commands in config/configuration.yml. Please restart the application after editing it.
   text_scm_command_not_available: Scm command is not available. Please check settings on the administration panel.
+  label_add_to_all_workflows: Add to all workflows
+  error_unable_add_to_workflows: Unable to add issue status to all workflows. Please add it manually.
diff --git a/config/locales/tr.yml b/config/locales/tr.yml
index 02fa5ea..01a115d 100644
--- a/config/locales/tr.yml
+++ b/config/locales/tr.yml
@@ -996,3 +996,5 @@ tr:
   label_git_report_last_commit: Report last commit for files and directories
   text_scm_config: You can configure your scm commands in config/configuration.yml. Please restart the application after editing it.
   text_scm_command_not_available: Scm command is not available. Please check settings on the administration panel.
+  label_add_to_all_workflows: Add to all workflows
+  error_unable_add_to_workflows: Unable to add issue status to all workflows. Please add it manually.
diff --git a/config/locales/uk.yml b/config/locales/uk.yml
index 9e999e9..7855ee6 100644
--- a/config/locales/uk.yml
+++ b/config/locales/uk.yml
@@ -973,3 +973,5 @@ uk:
   label_git_report_last_commit: Report last commit for files and directories
   text_scm_config: You can configure your scm commands in config/configuration.yml. Please restart the application after editing it.
   text_scm_command_not_available: Scm command is not available. Please check settings on the administration panel.
+  label_add_to_all_workflows: Add to all workflows
+  error_unable_add_to_workflows: Unable to add issue status to all workflows. Please add it manually.
diff --git a/config/locales/vi.yml b/config/locales/vi.yml
index 00a3081..bea439b 100644
--- a/config/locales/vi.yml
+++ b/config/locales/vi.yml
@@ -1028,3 +1028,5 @@ vi:
   label_git_report_last_commit: Report last commit for files and directories
   text_scm_config: You can configure your scm commands in config/configuration.yml. Please restart the application after editing it.
   text_scm_command_not_available: Scm command is not available. Please check settings on the administration panel.
+  label_add_to_all_workflows: Add to all workflows
+  error_unable_add_to_workflows: Unable to add issue status to all workflows. Please add it manually.
diff --git a/config/locales/zh-TW.yml b/config/locales/zh-TW.yml
index 61e593c..baa2e5b 100644
--- a/config/locales/zh-TW.yml
+++ b/config/locales/zh-TW.yml
@@ -1058,3 +1058,5 @@
   enumeration_doc_categories: 文件分類
   enumeration_activities: 活動 (時間追蹤)
   enumeration_system_activity: 系統活動
+  label_add_to_all_workflows: Add to all workflows
+  error_unable_add_to_workflows: Unable to add issue status to all workflows. Please add it manually.
diff --git a/config/locales/zh.yml b/config/locales/zh.yml
index 4b94583..58c33e9 100644
--- a/config/locales/zh.yml
+++ b/config/locales/zh.yml
@@ -980,3 +980,5 @@ zh:
   label_git_report_last_commit: Report last commit for files and directories
   text_scm_config: You can configure your scm commands in config/configuration.yml. Please restart the application after editing it.
   text_scm_command_not_available: Scm command is not available. Please check settings on the administration panel.
+  label_add_to_all_workflows: Add to all workflows
+  error_unable_add_to_workflows: Unable to add issue status to all workflows. Please add it manually.
